"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var graphql_1 = require("graphql");
var visitor_1 = require("./visitor");
exports.plugin = function (schema, documents, config) {
    var imports = ['GraphQLResolveInfo'];
    var hasScalars = Object.values(schema.getTypeMap())
        .filter(function (t) { return t.astNode; })
        .some(graphql_1.isScalarType);
    if (hasScalars) {
        imports.push('GraphQLScalarType', 'GraphQLScalarTypeConfig');
    }
    var visitor = new visitor_1.TypeScriptResolversVisitor(config, schema);
    var header = "\nimport { " + imports.join(', ') + " } from 'graphql';\n\nexport type ResolverFn<TResult, TParent, TContext, TArgs> = (\n  parent?: TParent,\n  args?: TArgs,\n  context?: TContext,\n  info?: GraphQLResolveInfo\n) => Promise<TResult> | TResult;\n\nexport type StitchingResolver<TResult, TParent, TContext, TArgs> = {\n  fragment: string;\n  resolve: ResolverFn<TResult, TParent, TContext, TArgs>;\n};\n\nexport type Resolver<TResult, TParent = {}, TContext = {}, TArgs = {}> =\n  | ResolverFn<TResult, TParent, TContext, TArgs>\n  | StitchingResolver<TResult, TParent, TContext, TArgs>;\n\nexport type SubscriptionSubscribeFn<TResult, TParent, TContext, TArgs> = (\n  parent?: TParent,\n  args?: TArgs,\n  context?: TContext,\n  info?: GraphQLResolveInfo\n) => AsyncIterator<TResult> | Promise<AsyncIterator<TResult>>;\n\nexport type SubscriptionResolveFn<TResult, TParent, TContext, TArgs> = (\n  parent?: TParent,\n  args?: TArgs,\n  context?: TContext,\n  info?: GraphQLResolveInfo\n) => TResult | Promise<TResult>;\n\nexport interface ISubscriptionResolverObject<TResult, TParent, TContext, TArgs> {\n  subscribe: SubscriptionSubscribeFn<TResult, TParent, TContext, TArgs>;\n  resolve?: SubscriptionResolveFn<TResult, TParent, TContext, TArgs>;\n}\n\nexport type SubscriptionResolver<TResult, TParent = {}, TContext = {}, TArgs = {}> =\n  | ((...args: any[]) => ISubscriptionResolverObject<TResult, TParent, TContext, TArgs>)\n  | ISubscriptionResolverObject<TResult, TParent, TContext, TArgs>;\n\nexport type TypeResolveFn<TTypes, TParent = {}, TContext = {}> = (\n  parent?: TParent,\n  context?: TContext,\n  info?: GraphQLResolveInfo\n) => Maybe<TTypes>;\n\nexport type NextResolverFn<T> = () => Promise<T>;\n\nexport type DirectiveResolverFn<TResult = {}, TParent = {}, TContext = {}, TArgs = {}> = (\n  next?: NextResolverFn<TResult>,\n  parent?: TParent,\n  args?: TArgs,\n  context?: TContext,\n  info?: GraphQLResolveInfo\n) => TResult | Promise<TResult>;\n";
    var printedSchema = graphql_1.printSchema(schema);
    var astNode = graphql_1.parse(printedSchema);
    var visitorResult = graphql_1.visit(astNode, { leave: visitor });
    var getRootResolver = visitor.getRootResolver, getAllDirectiveResolvers = visitor.getAllDirectiveResolvers, mappersImports = visitor.mappersImports;
    return mappersImports.concat([
        header
    ], visitorResult.definitions.filter(function (d) { return typeof d === 'string'; }), [
        getRootResolver(),
        getAllDirectiveResolvers()
    ]).join('\n');
};
//# sourceMappingURL=index.js.map